@@ -2,10 +2,10 @@
 
 set -e
 
-TAG="lazka/pygobject:v3"
+TAG="registry.gitlab.gnome.org/gnome/pygobject/main:v6"
 
 sudo docker build --build-arg HOST_USER_ID="$UID" --tag "${TAG}" \
     --file "Dockerfile" .
-sudo docker run -e PYENV_VERSION='3.6.5' --rm \
+sudo docker run -e PYENV_VERSION='3.6.5' --rm --security-opt label=disable \
     --volume "$(pwd)/..:/home/user/app" --workdir "/home/user/app" \
     --tty --interactive "${TAG}" bash
