@@ -47,8 +47,8 @@ pygi_gpointer_from_py (PyObject *py_arg, gpointer *result)
     if (py_arg == Py_None) {
         *result = NULL;
         return TRUE;
-    } else if (PYGLIB_CPointer_Check(py_arg)) {
-        temp = PYGLIB_CPointer_GetPointer (py_arg, NULL);
+    } else if (PyCapsule_CheckExact (py_arg)) {
+        temp = PyCapsule_GetPointer (py_arg, NULL);
         if (temp == NULL)
             return FALSE;
         *result = temp;
@@ -102,7 +102,7 @@ base_float_checks (PyObject *object)
 {
     if (!PyNumber_Check (object)) {
         PyErr_Format (PyExc_TypeError, "Must be number, not %s",
-                      object->ob_type->tp_name);
+                      Py_TYPE (object)->tp_name);
         return NULL;
     }
 
@@ -212,7 +212,7 @@ pygi_gunichar_from_py (PyObject *py_arg, gunichar *result)
 #endif
     } else {
        PyErr_Format (PyExc_TypeError, "Must be string, not %s",
-                     py_arg->ob_type->tp_name);
+                     Py_TYPE (py_arg)->tp_name);
        return FALSE;
     }
 
@@ -260,7 +260,7 @@ pygi_gtype_from_py (PyObject *py_arg, GType *type)
 
     if (temp == 0) {
         PyErr_Format (PyExc_TypeError, "Must be gobject.GType, not %s",
-                      py_arg->ob_type->tp_name);
+                      Py_TYPE (py_arg)->tp_name);
         return FALSE;
     }
 
@@ -294,7 +294,7 @@ pygi_utf8_from_py (PyObject *py_arg, gchar **result)
 #endif
     else {
         PyErr_Format (PyExc_TypeError, "Must be string, not %s",
-                      py_arg->ob_type->tp_name);
+                      Py_TYPE (py_arg)->tp_name);
         return FALSE;
     }
 
@@ -343,7 +343,7 @@ filename_from_py_unix (PyObject *py_arg, gchar **result)
         Py_DECREF (bytes);
     } else {
         PyErr_Format (PyExc_TypeError, "Must be bytes, not %s",
-                      py_arg->ob_type->tp_name);
+                      Py_TYPE (py_arg)->tp_name);
         return FALSE;
     }
 
@@ -387,7 +387,7 @@ filename_from_py_win32 (PyObject *py_arg, gchar **result)
         Py_DECREF (bytes);
     } else {
         PyErr_Format (PyExc_TypeError, "Must be unicode, not %s",
-                      py_arg->ob_type->tp_name);
+                      Py_TYPE (py_arg)->tp_name);
         return FALSE;
     }
 #else
@@ -437,7 +437,7 @@ filename_from_py_win32 (PyObject *py_arg, gchar **result)
         Py_DECREF (bytes);
     } else {
         PyErr_Format (PyExc_TypeError, "Must be str, not %s",
-                      py_arg->ob_type->tp_name);
+                      Py_TYPE (py_arg)->tp_name);
         return FALSE;
     }
 #endif
@@ -463,7 +463,7 @@ base_number_checks (PyObject *object)
 
     if (!PyNumber_Check (object)) {
         PyErr_Format (PyExc_TypeError, "Must be number, not %s",
-                      object->ob_type->tp_name);
+                      Py_TYPE (object)->tp_name);
         return NULL;
     }
 
@@ -505,6 +505,55 @@ pygi_gboolean_to_py (gboolean value)
     return PyBool_FromLong (value);
 }
 
+/* A super set of pygi_gint8_from_py (also handles unicode) */
+gboolean
+pygi_gschar_from_py (PyObject *object, gint8 *result)
+{
+    if (PyUnicode_Check (object)) {
+        gunichar uni;
+        PyObject *temp;
+        gboolean status;
+
+        if (!pygi_gunichar_from_py (object, &uni))
+            return FALSE;
+
+        temp = pygi_guint32_to_py (uni);
+        status = pygi_gint8_from_py (temp, result);
+        Py_DECREF (temp);
+        return status;
+    } else {
+        /* pygi_gint8_from_py handles numbers and bytes */
+        return pygi_gint8_from_py (object, result);
+    }
+
+    return FALSE;
+}
+
+/* A super set of pygi_guint8_from_py (also handles unicode) */
+gboolean
+pygi_guchar_from_py (PyObject *object, guchar *result)
+{
+    if (PyUnicode_Check (object)) {
+        gunichar uni;
+        PyObject *temp;
+        gboolean status;
+        gint8 codepoint;
+
+        if (!pygi_gunichar_from_py (object, &uni))
+            return FALSE;
+
+        temp = pygi_guint32_to_py (uni);
+        status = pygi_gint8_from_py (temp, &codepoint);
+        Py_DECREF (temp);
+        if (status)
+            *result = (guchar)codepoint;
+        return status;
+    } else {
+        /* pygi_guint8_from_py handles numbers and bytes */
+        return pygi_guint8_from_py (object, result);
+    }
+}
+
 gboolean
 pygi_gint_from_py (PyObject *object, gint *result)
 {
@@ -662,7 +711,7 @@ pygi_gulong_to_py (gulong value)
         return PyLong_FromUnsignedLong (value);
 }
 
-static gboolean
+gboolean
 pygi_gint8_from_py (PyObject *object, gint8 *result)
 {
     long long_value;
@@ -710,7 +759,7 @@ pygi_gint8_to_py (gint8 value)
     return PYGLIB_PyLong_FromLong (value);
 }
 
-static gboolean
+gboolean
 pygi_guint8_from_py (PyObject *object, guint8 *result)
 {
     long long_value;
@@ -904,7 +953,7 @@ overflow:
     return FALSE;
 }
 
-static PyObject *
+PyObject *
 pygi_guint32_to_py (guint32 value)
 {
 #if (G_MAXUINT <= LONG_MAX)
