@@ -96,6 +96,7 @@ _get_child_info_by_name (PyGIBaseInfo *self, PyObject *py_name,
         return NULL;
 
     info = get_child_info_by_name ((GIObjectInfo*)self->info, name);
+    g_free (name);
     if (info == NULL) {
         Py_RETURN_NONE;
     }
@@ -326,6 +327,7 @@ _wrap_g_base_info_get_attribute (PyGIBaseInfo *self, PyObject *arg)
         return NULL;
 
     value = g_base_info_get_attribute (self->info, name);
+    g_free (name);
     if (value == NULL) {
         Py_RETURN_NONE;
     }
@@ -598,12 +600,7 @@ _function_info_call (PyGICallableInfo *self, PyObject *args, PyObject *kwargs)
                 py_str_name = tmp;
             }
 
-#if PY_VERSION_HEX < 0x03000000
-            str_name = PyString_AsString (py_str_name);
-#else
-            str_name = PyBytes_AsString (py_str_name);
-#endif
-
+            str_name = PYGLIB_PyBytes_AsString (py_str_name);
             if (strcmp (str_name, _safe_base_info_get_name (container_info))) {
                 PyErr_Format (PyExc_TypeError,
                               "%s constructor cannot be used to create instances of "
@@ -741,10 +738,11 @@ _wrap_g_callable_info_get_return_attribute (PyGIBaseInfo *self, PyObject *py_nam
 
     attr = g_callable_info_get_return_attribute (self->info, name);
     if (attr) {
-        return pygi_utf8_to_py (
-                g_callable_info_get_return_attribute (self->info, name));
+        g_free (name);
+        return pygi_utf8_to_py (attr);
     } else {
         PyErr_Format(PyExc_AttributeError, "return attribute %s not found", name);
+        g_free (name);
         return NULL;
     }
 }
