@@ -12,6 +12,7 @@ import sys
 import os
 import re
 import platform
+import gc
 
 import pytest
 
@@ -1330,7 +1331,7 @@ class TestBoxed(unittest.TestCase):
         with warnings.catch_warnings(record=True) as warn:
             warnings.simplefilter('always')
             boxed = Everything.TestBoxedB(42, 47)
-            self.assertTrue(issubclass(warn[0].category, TypeError))
+            self.assertTrue(issubclass(warn[0].category, DeprecationWarning))
 
         self.assertEqual(boxed.some_int8, 0)
         self.assertEqual(boxed.some_long, 0)
@@ -1353,6 +1354,8 @@ class TestBoxed(unittest.TestCase):
         # - another owned by @obj
         self.assertEqual(obj.refcount, 2)
         del wrapper
+        gc.collect()
+        gc.collect()
         self.assertEqual(obj.refcount, 1)
 
     def test_boxed_c_wrapper_copy(self):
@@ -1367,10 +1370,16 @@ class TestBoxed(unittest.TestCase):
         # - another owned by @obj
         self.assertEqual(obj.refcount, 3)
         del wrapper
+        gc.collect()
+        gc.collect()
         self.assertEqual(obj.refcount, 2)
         del wrapper_copy
+        gc.collect()
+        gc.collect()
         self.assertEqual(obj.refcount, 1)
         del obj
+        gc.collect()
+        gc.collect()
 
     def test_array_fixed_boxed_none_out(self):
         arr = Everything.test_array_fixed_boxed_none_out()
